==> tine20-allinone_2020.03.4.tar.bz2: ActiveSync/js/ActiveSync-lang-th-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of ActiveSync **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/ActiveSync'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:48+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Thai (http://www.transifex.com/tine20/tine20/language/th/)\nLanguage: th\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Default Address book"
: ""

, "The default address book to create new contacts in."
: ""

, "Default Calendar"
: "ปฏิทินหลัก"

, "The default calendar to create new events in."
: "ปฏิทินหลักที่จะสร้างเหตุการณ์ใหม่เข้าไป"

, "Default Task List"
: "รายชื่อหน้าที่หลัก"

, "The default task list to create new tasks in."
: "รายชื่อหน้าที่หลักเพื่อสร้างหน้าที่ใหม่เข้า"

, "Sync Devices"
: ""

, "Device ID"
: ""

, "Devicetype"
: ""

, "Owner"
: ""

, "Policy"
: ""

, "ActiveSync Version"
: ""

, "User agent"
: ""

, "Model"
: ""

, "IMEI"
: ""

, "Friendly Name"
: ""

, "OS"
: ""

, "OS Language"
: ""

, "Phonenumber"
: ""

, "Sync Device, Sync Devices"
: [
  ""

]
, "Device, Devices"
: [
  "อุปกรณ์"

]
, "Devices"
: "อุปกรณ์"

, "Active Sync"
: ""

, "Select a Device"
: "เลือกอุปกรณ์"

, "No ActiveSync Device registered"
: ""

, "Set as {0} Filter"
: "ตั้งเป็นตัวกรอง {0}"

, "Resetted Sync Filter"
: ""

, "{0} filter for device \"{1}\" is now \"{2}\""
: "ตัวกรอง {0} สำหรับอุปกรณ์ \"{1}\" ตอนนี้เป็น \"{2}\""

, "resetted"
: ""

, "Set Sync Filter"
: ""

, "ID"
: ""

, "Device Type"
: ""

, "Operating System"
: ""

, "Phone Number"
: ""

, "Ping Lifetime"
: ""

, "Ping Folder"
: ""

, "Remote Wipe"
: ""

, "Calendar Filter"
: ""

, "Contacts Filter"
: ""

, "E-mail Filter"
: ""

, "Tasks Filter"
: ""

, "Last Ping"
: ""

, "Monitor Last Ping"
: ""

, "Remote Device Reset"
: ""

, "Please Confirm"
: ""

, "Do you really want to wipe the selected devices? All personal data will be removed and the device will be reset to factory settings!"
: ""

, "Quicksearch"
: ""

, "Default Policy"
: "นโยบายหลัก"

, "Default Policy installed during setup"
: "นโยบายหลักได้ถูกคัดลอกแล้วระหว่างการติดตั้ง"

, "Default policy for new devices"
: "นโยบายหลักสำหรับอุปกรณ์ใหม่"

, "Enter the id of the policy to apply to newly created devices."
: "ใส่รหัสของนโยบายเพื่อใช้สำหรับอุปกรณ์ที่เพิ่งสร้างขึ้น"

, "User Agent Deny List"
: ""

, "Array of regular expressions of User-Agent strings"
: ""

, "Disable Access Log"
: "ไม่สามารถบันทึกการใช้งาน"

, "Disable ActiveSync Access Log creation."
: ""

, "Filter timeslot for e-mails"
: ""

, "For how long in the past the e-mails should be synchronized."
: ""

, "Filter timeslot for events"
: "ตัวกรองช่วงเวลาสำหรับเหตุการณ์ต่าง ๆ"

, "For how long in the past the events should be synchronized."
: "ระยะเวลานานแค่ไหนในอดีที่เหตุการณ์ควรจะได้รับการอัพเดท"

, "Manage ActiveSync devices"
: ""

, "See, edit and delete ActiveSync devices"
: ""

, "Reset ActiveSync devices"
: ""

, "Remotely reset ActiveSync devices to factory state, deleting all data"
: ""





, "Sync Device"
: ""

, "Device"
: "อุปกรณ์"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: ActiveSync/js/ActiveSync-lang-th-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of ActiveSync **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/ActiveSync'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:43+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Thai (http://www.transifex.com/tine20/tine20/language/th/)\nLanguage: th\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Active Sync"
: ""

, "Select a Device"
: "เลือกอุปกรณ์"

, "No ActiveSync Device registered"
: ""

, "Set as {0} Filter"
: "ตั้งเป็นตัวกรอง {0}"

, "Resetted Sync Filter"
: ""

, "{0} filter for device \"{1}\" is now \"{2}\""
: "ตัวกรอง {0} สำหรับอุปกรณ์ \"{1}\" ตอนนี้เป็น \"{2}\""

, "resetted"
: ""

, "Set Sync Filter"
: ""

, "Sync Devices"
: ""

, "ID"
: ""

, "Device ID"
: ""

, "Device Type"
: ""

, "Owner"
: ""

, "Policy"
: ""

, "ActiveSync Version"
: ""

, "User agent"
: ""

, "Model"
: ""

, "IMEI"
: ""

, "Friendly Name"
: ""

, "Operating System"
: ""

, "OS Language"
: ""

, "Phone Number"
: ""

, "Ping Lifetime"
: ""

, "Ping Folder"
: ""

, "Remote Wipe"
: ""

, "Calendar Filter"
: ""

, "Contacts Filter"
: ""

, "E-mail Filter"
: ""

, "Tasks Filter"
: ""

, "Last Ping"
: ""

, "Monitor Last Ping"
: ""

, "Remote Device Reset"
: ""

, "Please Confirm"
: ""

, "Do you really want to wipe the selected devices? All personal data will be removed and the device will be reset to factory settings!"
: ""

, "Quicksearch"
: ""

, "Sync Device, Sync Devices"
: [
  ""

]
, "Device, Devices"
: [
  "อุปกรณ์"

]
, "Devices"
: "อุปกรณ์"

, "Devicetype"
: ""

, "OS"
: ""

, "Phonenumber"
: ""

, "Default Address book"
: ""

, "The default address book to create new contacts in."
: ""

, "Default Calendar"
: "ปฏิทินหลัก"

, "The default calendar to create new events in."
: "ปฏิทินหลักที่จะสร้างเหตุการณ์ใหม่เข้าไป"

, "Default Task List"
: "รายชื่อหน้าที่หลัก"

, "The default task list to create new tasks in."
: "รายชื่อหน้าที่หลักเพื่อสร้างหน้าที่ใหม่เข้า"

, "Default policy for new devices"
: "นโยบายหลักสำหรับอุปกรณ์ใหม่"

, "Enter the id of the policy to apply to newly created devices."
: "ใส่รหัสของนโยบายเพื่อใช้สำหรับอุปกรณ์ที่เพิ่งสร้างขึ้น"

, "Device Model Agent Deny List"
: ""

, "Array of regular expressions of Device-Model strings"
: ""

, "User Agent Deny List"
: ""

, "Array of regular expressions of User-Agent strings"
: ""

, "Disable Access Log"
: "ไม่สามารถบันทึกการใช้งาน"

, "Disable ActiveSync Access Log creation."
: ""

, "Filter timeslot for e-mails"
: ""

, "For how long in the past the e-mails should be synchronized."
: ""

, "Filter timeslot for events"
: "ตัวกรองช่วงเวลาสำหรับเหตุการณ์ต่าง ๆ"

, "For how long in the past the events should be synchronized."
: "ระยะเวลานานแค่ไหนในอดีที่เหตุการณ์ควรจะได้รับการอัพเดท"

, "%1$s ActiveSync failure"
: ""

, "Dear user,"
: ""

, "%1$s has noticed that the syncronization with your ActiveSync device is no longer active. Please trigger the syncronisation on your device."
: ""

, "Thank you."
: ""

, "Your %1$s Team"
: ""

, "Default Policy"
: "นโยบายหลัก"

, "Default Policy installed during setup"
: "นโยบายหลักได้ถูกคัดลอกแล้วระหว่างการติดตั้ง"

, "Manage ActiveSync devices"
: ""

, "See, edit and delete ActiveSync devices"
: ""

, "Reset ActiveSync devices"
: ""

, "Remotely reset ActiveSync devices to factory state, deleting all data"
: ""





, "Sync Device"
: ""

, "Device"
: "อุปกรณ์"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
